@@ -28,6 +28,8 @@
 #include <sys/types.h>
 #include <stdlib.h>
 #include <signal.h>
+#include <errno.h>
+#include <sys/file.h>
 #include <grp.h>
 #include <pwd.h>
 #include <limits.h>
@@ -46,7 +48,6 @@
 #include "trayappletui.h"
 
 /* some prototypes */
-extern gboolean up_get_clipboard (void);
 gboolean update_timer_finished(gpointer data);
 
 // the time when we check for fam events, in seconds
@@ -535,6 +536,8 @@ main (int argc, char **argv)
 {
 	UpgradeNotifier *un;
 	GError *error = NULL;
+	int pid_file, rc;
+	gchar *lockfn;
 
 	// init
 	if(!gtk_init_with_args (&argc, &argv,
@@ -582,7 +585,11 @@ main (int argc, char **argv)
 	}
 
 	// check if it is running already
-	if (!up_get_clipboard ()) {
+	lockfn = g_build_filename (g_get_user_runtime_dir (), "update-notifier.pid", NULL);
+	pid_file = open (lockfn, O_CREAT | O_RDWR, 0600);
+	g_free (lockfn);
+	rc = flock(pid_file, LOCK_EX | LOCK_NB);
+	if (rc) {
 	   g_warning ("already running?");
 	   return 1;
 	}
